@@ -7,6 +7,7 @@ import re
 # DJANGO IMPORTS
 from django.core.management.base import BaseCommand, CommandError
 from django.conf import settings
+from django.utils.six.moves import input
 
 # FILEBROWSER IMPORTS
 from filebrowser.settings import EXTENSION_LIST, EXCLUDE, DIRECTORY, VERSIONS, EXTENSIONS
@@ -16,7 +17,7 @@ from filebrowser.base import FileListing, FileObject
 filter_re = []
 for exp in EXCLUDE:
     filter_re.append(re.compile(exp))
-for k, v in VERSIONS.iteritems():
+for k, v in VERSIONS.items():
     exp = (r'_%s(%s)') % (k, '|'.join(EXTENSION_LIST))
     filter_re.append(re.compile(exp))
 
@@ -43,7 +44,7 @@ class Command(BaseCommand):
             for version in VERSIONS:
                 self.stdout.write(' * %s\n' % version)
 
-            version_name = raw_input('(leave blank to generate all versions): ')
+            version_name = input('(leave blank to generate all versions): ')
 
             if version_name == "":
                 selected_version = None
